@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Mock::Sub::Child;
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 sub new {
     my $self = bless {}, shift;
@@ -62,8 +62,8 @@ sub mocked_objects {
     my $self = shift;
 
     my @mocked;
-    for (keys %{ $self->{mocked} }){
-        push @mocked, $self->{mocked}{$_}{object};
+    for (keys %{ $self->{objects} }){
+        push @mocked, $self->{objects}{$_}{obj};
     }
     return @mocked;
 }
@@ -93,6 +93,9 @@ sub __end {}; # vim fold placeholder
 
 Mock::Sub - Mock package, object and standard subroutines, with unit testing in mind.
 
+=for html
+<a href="http://travis-ci.org/stevieb9/mock-sub"><img src="https://secure.travis-ci.org/stevieb9/mock-sub.png"/>
+<a href='https://coveralls.io/github/stevieb9/mock-sub?branch=master'><img src='https://coveralls.io/repos/stevieb9/mock-sub/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -110,7 +113,7 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
     my $foo = $mock->mock('Package::foo');
     my $bar = $mock->mock('Package::bar');
 
-    # wait until the mocked sub is called
+    # wait until a mocked sub is called
 
     Package::foo();
 
@@ -123,14 +126,14 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
 
     # have the mocked sub return something when it's called (list or scalar).
     # See new() to find out how to set a return value once and have it used in
-    # all child mocks
+    # all child mocked subs
 
     $foo->return_value(1, 2, {a => 1});
     my @return = Package::foo;
 
     # have the mocked sub perform an action (the side effect function receives
     # the parameters sent into the mocked sub). See new() to find out how to
-    # set side_effect up once, and have it copied to all child mocks
+    # set side_effect up once, and have it copied to all child mocked subs
 
     $foo->side_effect( sub { die "eval catch" if @_; } );
 
@@ -154,7 +157,7 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
 
     # re-mock a sub using the same object after unmocking (this is the only
     # time void context with mock() is permitted). Note that child mocks don't
-    # take a sub parameter to mock()
+    # take a sub parameter to mock(), as they simply re-mock their original sub
 
     $foo->mock;
 
@@ -393,12 +396,8 @@ L<https://github.com/stevieb9/mock-sub>
 
 =head1 BUILD RESULTS
 
-Travis-CI: L<https://travis-ci.org/stevieb9/mock-sub>
-
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=Mock-Sub>
 
-Coverage: L<https://coveralls.io/github/stevieb9/mock-sub>
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
